Changes
=======

0.4 (2014-03-14)
----------------

- Improved OpenCorpora -> RusCorpora rules;
- Anph grammeme is added to OpenCorpora rules.

0.3.1 (2013-04-12)
------------------

- Improved OpenCorpora -> RusCorpora rules.

0.3 (2013-03-21)
----------------

- Improved OpenCorpora -> RusCorpora rules.

0.2 (2013-02-07)
----------------

- OpenCorpora -> RusCorpora conversion;
- DSL for writing conversion routines.

0.1 (2012-10-07)
----------------

Initial release
